<?php
/** 
 * @package WordPress
 * @subpackage Eviro
 * based on WP-Bootstrap
 */



include ( get_stylesheet_directory() . '/includes/theme-options.php' );

/**
 * Load Google Webfonts
 */
function eviro_load_fonts() {
    wp_register_style('googleFonts', 'http://fonts.googleapis.com/css?family=PT+Sans%7CTelex');
    wp_enqueue_style( 'googleFonts');
    } 
    add_action('wp_enqueue_scripts', 'eviro_load_fonts');

/**
 * Maximum allowed width of content within the theme.
 */
if (!isset($content_width)) {
    $content_width = 770;
}

/**
 * Setup Theme Functions
 *
 */
if (!function_exists('eviro_theme_setup')):
    function eviro_theme_setup() {
	
		load_theme_textdomain('eviro', get_template_directory() . '/lang');
  
		add_theme_support( 'custom-background' );
		$args=array("header-text"=>false);
		add_theme_support( 'custom-header',$args);
		
        add_theme_support('automatic-feed-links');
        add_theme_support('post-thumbnails');
        add_theme_support('post-formats', array( 'aside', 'image', 'gallery', 'link', 'quote', 'status', 'video', 'audio', 'chat' ));

		add_theme_support( 'post-thumbnails' ); 
		add_image_size( 'sliding-images', 1170, 400, true ); 

    	set_post_thumbnail_size(260, 180); // 260px wide x 180px high
    	add_image_size('bootstrap-small', 300, 200); // 300px wide x 200px high
    	add_image_size('bootstrap-medium', 360, 270); // 360px wide by 270px high


        register_nav_menus(
            array(
                'main-menu' => "Main menu",
            ));
        // load custom walker menu class file 
    }
endif;
add_action('after_setup_theme', 'eviro_theme_setup');
 

/**
 * Load CSS styles for theme.
 *
 */
function eviro_styles_loader() {

    wp_enqueue_style('bootstrapwp-style', get_template_directory_uri() . '/assets/css/bootstrapwp.css', false, '1.0', 'all');
    wp_enqueue_style('bootstrapwp-default', get_stylesheet_uri());

    // registering scripts and styles for documentation templates
    wp_register_style('docs-css', get_template_directory_uri() . '/templates-documentation/assets/css/docs.css', array('bootstrapwp-style'), '2.3.2', 'all');

}
add_action('wp_enqueue_scripts', 'eviro_styles_loader');

/**
 * Load JavaScript and jQuery files for theme.
 *
 */
function eviro_scripts_loader() {

    if (is_singular() && comments_open() && get_option('thread_comments')) {

        wp_enqueue_script('comment-reply');

    }

    wp_enqueue_script('bootstrap-js', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array('jquery'), '1.0', true);
    wp_enqueue_script('demo-js', get_template_directory_uri() . '/assets/js/bootstrapwp.demo.js', array('bootstrap-js'),'1.0',true);

}
add_action('wp_enqueue_scripts', 'eviro_scripts_loader');

/**
 * Define theme's widget areas.
 *
 */
function eviro_widgets_init() {

    register_sidebar(
        array(
            'name'          => 'Page Sidebar',
            'id'            => 'sidebar-page',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => "</div>",
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>',
        )
    );

    register_sidebar(
        array(
            'name'          => 'Posts Sidebar',
            'id'            => 'sidebar-posts',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => "</div>",
            'before_title'  => '<h4 class="widget-title">',
            'after_title'   => '</h4>',
        )
    );

    register_sidebar(
        array(
            'name'          => 'Home Left',
            'id'            => 'home-left',
            'description'   => 'Left textbox on homepage',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h2>',
            'after_title'   => '</h2>'
        )
    );

    register_sidebar(
        array(
            'name'          => 'Home Middle',
            'id'            => 'home-middle',
            'description'   => 'Middle textbox on homepage',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h2>',
            'after_title'   => '</h2>'
        )
    );

    register_sidebar(
        array(
            'name'          => 'Home Right',
            'id'            => 'home-right',
            'description'   => 'Right textbox on homepage',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h2>',
            'after_title'   => '</h2>'
        )
    );

    register_sidebar(
        array(
            'name'          => 'Footer Content',
            'id'            => 'footer-content',
            'description'   => 'Footer text or acknowledgements',
            'before_widget' => '<div id="%1$s" class="widget %2$s">',
            'after_widget'  => '</div>',
            'before_title'  => '<h4>',
            'after_title'   => '</h4>'
        )
    );

}
add_action('widgets_init', 'eviro_widgets_init');


/**
 * Display page next/previous navigation links.
 *
 */
if (!function_exists('eviro_content_nav')):
    function eviro_content_nav($nav_id) {

        global $wp_query, $post;

        if ($wp_query->max_num_pages > 1) : ?>

        <nav id="<?php echo $nav_id; ?>" class="navigation" role="navigation">
            <h3 class="assistive-text">Post navigation</h3>
            <div class="nav-previous alignleft"><?php next_posts_link(); ?></div>
            <div class="nav-next alignright"><?php previous_posts_link(); ?></div>
        </nav><!-- #<?php echo $nav_id; ?> .navigation -->

        <?php endif;
    }
endif;

/**
 * Display template for comments and pingbacks.
 *
 */
if (!function_exists('eviro_comment')) :
    function eviro_comment($comment, $args, $depth)
    {
        $GLOBALS['comment'] = $comment;
        switch ($comment->comment_type) :
            case 'pingback' :
            case 'trackback' : ?>

                <li class="comment media" id="comment-<?php comment_ID(); ?>">
                    <div class="media-body">
                        <p>Pingback: <?php comment_author_link(); ?></p>
                    </div><!--/.media-body -->
                <?php
                break;
            default :
                // Proceed with normal comments.
                global $post; ?>

                <li class="comment media" id="li-comment-<?php comment_ID(); ?>">
                        <a href="<?php echo $comment->comment_author_url;?>" class="pull-left">
                            <?php echo get_avatar($comment, 64); ?>
                        </a>
                        <div class="media-body">
                            <h4 class="media-heading comment-author vcard">
                                <?php
                                printf('<cite class="fn">%1$s %2$s</cite>',
                                    get_comment_author_link(),
                                    // If current post author is also comment author, make it known visually.
                                    ($comment->user_id === $post->post_author) ? '<span class="label"> ' .  'Post author' . '</span> ' : ''); ?>
                            </h4>

                            <?php if ('0' == $comment->comment_approved) : ?>
                                <p class="comment-awaiting-moderation">Your comment is awaiting moderation.</p>
                            <?php endif; ?>

                            <?php comment_text(); ?>
                            <p class="meta">
                               <a href="<?php echo get_comment_date(); ?>"><time datetime="<?php get_comment_date(); ?>"></time></a> 
                            </p>
                            <p class="reply">
                                <?php comment_reply_link(); ?>
                            </p>
                        </div>
                        <!--/.media-body -->
                <?php
                break;
        endswitch;
    }
endif;


/**
 * Display template for post meta information.
 *
 */
if (!function_exists('eviro_posted_on')) :
    function eviro_posted_on()
    {
        ?>Posted on <?php echo get_the_category_list(", "); ?>
				<span class="byline"> <span class="sep"> by </span> <span class="author vcard"><a class="url fn n" href="<?php echo esc_url(get_author_posts_url(get_the_author_meta('ID'))); ?>" rel="author"><?php echo  esc_html(get_the_author()); ?></a></span> </span> 
   			<?php echo the_tags("<p>Tags: ", ", ", "</p>"); 
    }
endif;


/**
 * Adds custom classes to the array of body classes.
 *
 */
function eviro_body_classes($classes)
{
    if (!is_multi_author()) {
        $classes[] = 'single-author';
    }
    return $classes;
}
add_filter('body_class', 'eviro_body_classes');


/**
 * Add post ID attribute to image attachment pages prev/next navigation.
 *
 */
function eviro_enhanced_image_navigation($url)
{
    global $post;
    if (wp_attachment_is_image($post->ID)) {
        $url = $url . '#main';
    }
    return $url;
}
add_filter('attachment_link', 'eviro_enhanced_image_navigation');


/**
 * Checks if a post thumbnails is already defined.
 *
 */
function eviro_is_post_thumbnail_set()
{
    global $post;
    if (get_the_post_thumbnail()) {
        return true;
    } else {
        return false;
    }
}


/**
 * Set post thumbnail as first image from post, if not already defined.
 *
 */
function eviro_autoset_featured_img()
{
    global $post;

    $post_thumbnail = eviro_is_post_thumbnail_set();
    if ($post_thumbnail == true) {
        return get_the_post_thumbnail();
    }
    $image_args     = array(
        'post_type'      => 'attachment',
        'numberposts'    => 1,
        'post_mime_type' => 'image',
        'post_parent'    => $post->ID,
        'order'          => 'desc'
    );
    $attached_images = get_children($image_args, ARRAY_A);
    $first_image = reset($attached_images);
    if (!$first_image) {
        return false;
    }

    return get_the_post_thumbnail($post->ID, $first_image['ID']);

}


/**
 * Define default page titles.
 *
 */
function eviro_wp_title($title, $sep)
{
    global $paged, $page;
    if (is_feed()) {
        return $title;
    }
    // Add the site name.
    $title .= get_bloginfo('name');
    // Add the site description for the home/front page.
    $site_description = get_bloginfo('description', 'display');
    if ($site_description && (is_home() || is_front_page())) {
        $title = "$title $sep $site_description";
    }
    // Add a page number if necessary.
    if ($paged >= 2 || $page >= 2) {
        $title = "$title $sep";
    }
    return $title;
}
add_filter('wp_title', 'eviro_wp_title', 10, 2);

/**
 * Display template for breadcrumbs.
 *
 */
function eviro_breadcrumbs()
{
    $home      = 'Home'; // text for the 'Home' link
    $before    = '<li class="active">'; // tag before the current crumb
    $sep       = '<span class="divider">/</span>';
    $after     = '</li>'; // tag after the current crumb

    if (!is_home() && !is_front_page() || is_paged()) {

        echo '<ul class="breadcrumb">';

        global $post;
        $homeLink = esc_url(home_url());
            echo '<li><a href="' . $homeLink . '">' . $home . '</a> '.$sep. '</li> ';
            if (is_category()) {
                global $wp_query;
                $cat_obj   = $wp_query->get_queried_object();
                $thisCat   = $cat_obj->term_id;
                $thisCat   = get_category($thisCat);
                $parentCat = get_category($thisCat->parent);
                if ($thisCat->parent != 0) {
                    echo get_category_parents($parentCat, true, $sep);
                }
                echo $before . 'Archive by category "' . single_cat_title('', false) . '"' . $after;
            } elseif (is_day()) {
                echo '<li><a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time(
                    'Y'
                ) . '</a></li> ';
                echo '<li><a href="' . get_month_link(get_the_time('Y'), get_the_time('m')) . '">' . get_the_time(
                    'F'
                ) . '</a></li> ';
                echo $before . get_the_time('d') . $after;
            } elseif (is_month()) {
                echo '<li><a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time(
                    'Y'
                ) . '</a></li> ';
                echo $before . get_the_time('F') . $after;
            } elseif (is_year()) {
                echo $before . get_the_time('Y') . $after;
            } elseif (is_single() && !is_attachment()) {
                if (get_post_type() != 'post') {
                    $post_type = get_post_type_object(get_post_type());
                    $slug      = $post_type->rewrite;
                    echo '<li><a href="' . $homeLink . '/' . $slug['slug'] . '/">' . $post_type->labels->singular_name . '</a></li> ';
                    echo $before . get_the_title() . $after;
                } else {
                    $cat = get_the_category();
                    $cat = $cat[0];
                    echo '<li>'.get_category_parents($cat, true, $sep).'</li>';
                    echo $before . get_the_title() . $after;
                }
            } elseif (!is_single() && !is_page() && get_post_type() != 'post' && !is_404()) {
                $post_type = get_post_type_object(get_post_type());
                if($post_type)
                	{
					echo $before . $post_type->labels->singular_name . $after;
					}
            } elseif (is_attachment()) {
                $parent = get_post($post->post_parent);
                $cat    = get_the_category($parent->ID);
                $cat    = $cat[0];
                echo get_category_parents($cat, true, $sep);
                echo '<li><a href="' . get_permalink(
                    $parent
                ) . '">' . $parent->post_title . '</a></li> ';
                echo $before . get_the_title() . $after;

            } elseif (is_page() && !$post->post_parent) {
                echo $before . get_the_title() . $after;
            } elseif (is_page() && $post->post_parent) {
                $parent_id   = $post->post_parent;
                $breadcrumbs = array();
                while ($parent_id) {
                    $page          = get_page($parent_id);
                    $breadcrumbs[] = '<li><a href="' . get_permalink($page->ID) . '">' . get_the_title(
                        $page->ID
                    ) . '</a>' . $sep . '</li>';
                    $parent_id     = $page->post_parent;
                }
                $breadcrumbs = array_reverse($breadcrumbs);
                foreach ($breadcrumbs as $crumb) {
                    echo $crumb;
                }
                echo $before . get_the_title() . $after;
            } elseif (is_search()) {
                echo $before . 'Search results for "' . get_search_query() . '"' . $after;
            } elseif (is_tag()) {
                echo $before . 'Posts tagged "' . single_tag_title('', false) . '"' . $after;
            } elseif (is_author()) {
                global $author;
                $userdata = get_userdata($author);
                echo $before . 'Articles posted by ' . $userdata->display_name . $after;
            } elseif (is_404()) {
                echo $before . 'Error 404' . $after;
            }
 

        echo '</ul>';

    }
}


function eviro_show_socials()
	{
	 $return="<ul id='social_entries' class='span6'>";
 	 $options = get_option( 'eviro_theme_options' ); 
	 if(isset($options['facebook']) AND ($options['facebook']!="")) {
		$return.='<li><a  class="social-icon facebook" href="'.esc_url($options['facebook']).'" target="_blank">Facebook</a></li>';
	 }
	 if(isset($options['twitter']) AND ($options['twitter']!="")) {
		$return.='<li><a class="social-icon twitter" href="'.esc_url($options['twitter']).'" target="_blank">Twitter</a></li>';
	 }	
		 if(isset($options['flickr']) AND ($options['flickr']!="")) {
		$return.='<li><a class="social-icon flickr" href="'.esc_url($options['flickr']).'" target="_blank">Flickr</a></li>';
	 }	
		 if(isset($options['youtube']) AND ($options['youtube']!="")) {
		$return.='<li><a class="social-icon youtube" href="'.esc_url($options['youtube']).'" target="_blank">Youtube</a></li>';
	 }	
	$return.="</ul><!-- social_entries -->";
	return $return;	
	}







//Featured posts slider
add_action("admin_init", "eviro_selection_meta_box");

	function eviro_selection_meta_box(){
		//add_meta_box("featured-post", "Set Featured", "featured_post", "post", "side", "low"); Uncomment this line and comment the below foreach loop if you want the Set Featured option only for posts
		$post_types_array = get_post_types();
		foreach ( $post_types_array as $post_type ) {
			add_meta_box("featured-post", "Set post as featured", "eviro_featured_post", $post_type, "side", "low");
		}
	}
	
	function eviro_featured_post(){
		global $post;
		$selected="";
		$meta_data = get_post_custom($post->ID);
		if($meta_data!=""){
		 	if(isset($meta_data["_featured_post"][0])){
				$featured_post = $meta_data["_featured_post"][0];
				$selected = ($meta_data["_featured_post"][0] == "yes") ? 'checked' : '';				
			}			
		} 
		echo "<p>";
		echo "<input $selected type='checkbox' name='featured_post' value='yes' />";
		echo "<label>Select this post as Featured.</label>";
		echo "</p>";
	}
	
	add_action('save_post', 'eviro_save_post_details');
	
	function eviro_save_post_details(){
		global $post;
		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) 
    	return;
    	if(isset($_POST['featured_post']))
    		{
			$featured_post = trim($_POST["featured_post"]);
			update_post_meta($post->ID, "_featured_post", $featured_post);				
			}
	}



function eviro_show_featured_posts($numbers) {
	global $post; 
	$output="";
	$featured_posts_array = get_posts( 'meta_key=_featured_post&meta_value=yes&numberposts=$numbers&post_status=publish');
	$output .= '<div class="slider-wrapper theme-default container">
					<div class="row">'; 
	$output .="<div class='span12'>";
	$output .= '<div id="slider" class="flexslider">';
	$output .="<ul class='slides'>";
	foreach ($featured_posts_array as $post) :  setup_postdata($post); 
		$slidertitle = "#slide".get_the_ID(); //assign the postID as title of the image
			if (  has_post_thumbnail() ) {
			 	$output .= "<li>".get_the_post_thumbnail(get_the_ID(), array(1170,400), array( "class" => "post_thumbnail", 'title' => $slidertitle )); 
				 }
			$caption = "<div id='flex_".get_the_ID()."' class='slider-html-caption'>
						<h2><a href='".get_permalink()."'>".get_the_title()."</a></h2>
						".get_the_excerpt()."
						</div>";
			$output.=$caption;
			$output.="</li>";
	endforeach;	 
	$output .= '</div>';
	$output .="</ul>";
	$output .= '</div></div></div>';
	return $output;
 wp_reset_query();
}




function eviro_include_flex_script() { 
		wp_register_script( 'flex', get_template_directory_uri().'/assets/js/jquery.flex.min.js');
		wp_enqueue_script( 'jquery' );
		wp_enqueue_script( 'flex' );
	}    
	 
	add_action('wp_enqueue_scripts', 'eviro_include_flex_script');
	 
	
	add_action('wp_footer', 'eviro_flex_init');
	function eviro_flex_init() {
		echo '<script type="text/javascript">
    	jQuery(document).ready(function() {
        jQuery("#slider").flexslider();
   	 	});
   		</script>';
	}










class Eviro_Walker_Nav_Menu extends Walker_Nav_Menu {


    /**
     * Opening tag for menu list before anything is added
     *
     *
     * @param array reference       &$output    Reference to class' $output
     * @param int                   $depth      Depth of menu (if nested)
     * @param array                 $args       Class args, unused here
     *
     * @return string $indent
     * @return array by-reference   &$output
     *
     */
    function start_lvl( &$output, $depth = 0, $args = array() ) {

        $indent = str_repeat("\t", $depth);
        $output .= "\n$indent<ul class=\"dropdown-menu\">\n";
    }

    /**
     * @see Walker::end_lvl()
     * @since 3.0.0
     *
     * @param string $output Passed by reference. Used to append additional content.
     * @param int $depth Depth of page. Used for padding.
     */
    function end_lvl( &$output, $depth = 0, $args = array() ) {
        $indent = str_repeat("\t", $depth);
        $output .= "$indent</ul>\n";
    }

} 