<?php
/**
 * Theme options 
 *
 * @package WordPress
 * @subpackage Eviro
 * based on WP-Bootstrap
 */
add_action( 'admin_init', 'eviro_theme_options_init' );
add_action( 'admin_menu', 'eviro_theme_options_add_page' );

/**
 * Init plugin options to white list our options
 */
function eviro_theme_options_init(){
	register_setting( 'eviro_options', 'eviro_theme_options', 'eviro_theme_options_validate' );
}

/**
 * Load up the menu page
 */
function eviro_theme_options_add_page() {
	add_theme_page(  'Theme Options', 'Theme Options', 'edit_theme_options', 'theme_options', 'eviro_theme_options_do_page' );
}
 

/**
 * Create the options page
 */
function eviro_theme_options_do_page() {

	if ( ! isset( $_REQUEST['settings-updated'] ) )
		$_REQUEST['settings-updated'] = false;

	?>
	<div class="wrap">
		<?php screen_icon(); echo "<h2>" . wp_get_theme()  .' Theme Options' . "</h2>"; ?>

		<?php if ( false !== $_REQUEST['settings-updated'] ) : ?>
		<div class="updated fade"><p><strong>Options saved</strong></p></div>
		<?php endif; ?>

		<form method="post" action="options.php">
			<?php settings_fields( 'eviro_options' ); ?>
			<?php $options = get_option( 'eviro_theme_options' ); ?>

			<table class="form-table">

				<?php
				/**
				 * Slide on Homepage
				 */
				?>
				<tr valign="top"><th scope="row">Slideshow</th>
					<td>
						<input id="eviro_theme_options[slider]" name="eviro_theme_options[slider]" type="checkbox" value="1" <?php checked( '1', $options['slider'] ); ?> />
						<label class="description" for="eviro_theme_options[slider]">Show slideshow on Homepage</label>
					</td>
				</tr>
				<tr valign="top"><th scope="row">Slides</th>
					<td>
						<input id="eviro_theme_options[slides]" class="regular-text" type="text" name="eviro_theme_options[slides]" value="<?php echo esc_attr( $options['slides'] ); ?>" />
						<label class="description" for="eviro_theme_options[slides]">The number of slides for the slideshow on the homepage</label>
					</td>
				</tr>
				<?php
				/**
				* SOCIAL MEDIA
				**/
				?>
				<tr valign="top"><th scope="row">Facebook</th>
					<td>
						<input id="eviro_theme_options[facebook]" class="regular-text" type="text" name="eviro_theme_options[facebook]" value="<?php echo esc_attr( $options['facebook'] ); ?>" />
						<label class="description" for="eviro_theme_options[facebook]">Link to your Facebook profile</label>
					</td>
				</tr>
				<tr valign="top"><th scope="row">Twitter</th>
					<td>
						<input id="eviro_theme_options[twitter]" class="regular-text" type="text" name="eviro_theme_options[twitter]" value="<?php echo esc_attr( $options['twitter'] ); ?>" />
						<label class="description" for="eviro_theme_options[twitter]">Link to your Twitter profile</label>
					</td>
				</tr>
				<tr valign="top"><th scope="row">Flickr</th>
					<td>
						<input id="eviro_theme_options[flickr]" class="regular-text" type="text" name="eviro_theme_options[flickr]" value="<?php echo esc_attr( $options['flickr'] ); ?>" />
						<label class="description" for="eviro_theme_options[flickr]">Link to your Flickr profile</label>
					</td>
				</tr>
				<tr valign="top"><th scope="row">Youtube</th>
					<td>
						<input id="eviro_theme_options[youtube]" class="regular-text" type="text" name="eviro_theme_options[youtube]" value="<?php echo esc_attr( $options['youtube'] ); ?>" />
						<label class="description" for="eviro_theme_options[youtube]">Link to your Youtube profile</label>
					</td>
				</tr>

			</table>

			<p class="submit">
				<input type="submit" class="button-primary" value="Save Options" />
			</p>
		</form>
	</div>
	<?php
}

/**
 * Sanitize and validate input. Accepts an array, return a sanitized array.
 */
function eviro_theme_options_validate( $input ) { 
	global $select_options, $radio_options; 
	
	
	
	if ( ! isset( $input['slider'] ) )
		$input['slider'] = null; 
		 
	if ( isset ( $input['slides'] ) )
		$input['slides'] = sanitize_text_field($input['slides']);
		
		
		
	if ( isset ( $input['facebook'] ) )
		$input['facebook'] = esc_url($input['facebook']);		
		
		

	if ( isset ( $input['twitter'] ) )
		$input['twitter'] = esc_url($input['twitter']);		
		
		

	if ( isset ( $input['flickr'] ) )
		$input['flickr'] = esc_url($input['flickr']);		
		
		

	if ( isset ( $input['youtube'] ) )
		$input['youtube'] = esc_url($input['youtube']);		
		
		
				
	return $input; 
}

// adapted from http://planetozh.com/blog/2009/05/handling-plugins-options-in-wordpress-28-with-register_setting/